@@ -130,6 +130,7 @@ class SQLCli(object):
         self.SQLExecuteHandler.Console = self.Console
         self.SQLExecuteHandler.SQLPerfFile = self.m_SQLPerf
         self.SQLExecuteHandler.m_Worker_Name = WorkerName
+        self.SQLExecuteHandler.logger = self.logger
         self.SQLMappingHandler.Console = self.Console
 
         # 默认的输出格式
@@ -1398,7 +1399,7 @@ class SQLCli(object):
     def execute_internal_command(self, arg, **_):
         # 创建数据文件, 根据末尾的rows来决定创建的行数
         # 此时，SQL语句中的回车换行符没有意义
-        matchObj = re.match(r"create\s+(.*)\s+file\s+(.*)\((.*)\)(\s+)?rows\s+(\d+)(\s+)?$",
+        matchObj = re.match(r"create\s+(.*?)\s+file\s+(.*?)\((.*)\)(\s+)?rows\s+(\d+)(\s+)?$",
                             arg, re.IGNORECASE | re.DOTALL)
         if matchObj:
             m_filetype = str(matchObj.group(1)).strip()
@@ -1417,7 +1418,7 @@ class SQLCli(object):
                 str(m_rows) + ' rows created Successful.')
             return
 
-        matchObj = re.match(r"create\s+(.*)\s+file\s+(.*)\((.*)\)(\s+)?$",
+        matchObj = re.match(r"create\s+(.*?)\s+file\s+(.*?)\((.*)\)(\s+)?$",
                             arg, re.IGNORECASE | re.DOTALL)
         if matchObj:
             m_filetype = str(matchObj.group(1)).strip()
@@ -1437,7 +1438,7 @@ class SQLCli(object):
             return
 
         #  在不同的文件中进行相互转换
-        matchObj = re.match(r"create\s+(.*)\s+file\s+(.*)\s+from\s+(.*)file(.*)(\s+)?$",
+        matchObj = re.match(r"create\s+(.*?)\s+file\s+(.*?)\s+from\s+(.*?)file(.*?)(\s+)?$",
                             arg, re.IGNORECASE | re.DOTALL)
         if matchObj:
             # 在不同的文件中相互转换
@@ -1453,7 +1454,7 @@ class SQLCli(object):
             return
 
         # 创建随机数Seed的缓存文件
-        matchObj = re.match(r"create\s+seeddatafile\s+(.*)\s+with\s+null\s+rows\s+(\d+)$",
+        matchObj = re.match(r"create\s+seeddatafile\s+(.*?)\s+with\s+null\s+rows\s+(\d+)$",
                             arg, re.IGNORECASE | re.DOTALL)
         if matchObj:
             m_strSeedFile = str(matchObj.group(1)).lstrip().rstrip()
@@ -1467,7 +1468,7 @@ class SQLCli(object):
             return
 
         # 创建随机数Seed的缓存文件
-        matchObj = re.match(r"create\s+seeddatafile\s+(.*)(\s+)?$",
+        matchObj = re.match(r"create\s+seeddatafile\s+(.*?)(\s+)?$",
                             arg, re.IGNORECASE | re.DOTALL)
         if matchObj:
             m_strSeedFile = str(matchObj.group(1))
